@@ -12,7 +12,7 @@ unite <- function(.data, name, col, sep) {
     mc <- match.call()
     dataname <- mc$.data
 
-    fmla <- "tidyr::unite(.NAME, .COL, sep = .SEP, remove = FALSE)"
+    fmla <- ".COLTRANStidyr::unite(.NAME, .COL, sep = .SEP, remove = FALSE)"
     if (is_survey(.data)) {
         exp <- ~.DATA %>%
             {
@@ -24,8 +24,21 @@ unite <- function(.data, name, col, sep) {
         exp <- ~.DATA %>% .FMLA %>% .FACTOR
     }
 
+    f_cols <- col
+    .fdata <- if (is_survey(.data)) .data$variables else .data
+    f_cols <- f_cols[sapply(.fdata[f_cols], function(x) is.factor(x) && any(is.na(x)))]
+    f_trans <- ""
+    if (length(f_cols)) {
+        f_trans <- paste(
+            f_cols, " = forcats::fct_explicit_na(", f_cols, ", 'NA')",
+            collapse = ", "
+        )
+        f_trans <- sprintf("dplyr::mutate(%s) %s ", f_trans, "%>%")
+    }
+
     exp <- replaceVars(exp,
         .FMLA = fmla,
+        .COLTRANS = f_trans,
         .FACTOR = "dplyr::mutate(.VNAME = as.factor(.VNAME))",
         .DATA = dataname,
         .VNAME = name
