@@ -1,11 +1,9 @@
-context("Append rows")
-
 cas <- smart_read("cas500.csv")
 # cas <- smart_read("tests/testthat/cas500.csv")
 
 test_that("Rows can be appended", {
     expect_silent(c2 <- appendrows(cas[1:400,], cas[-(1:400),]))
-    expect_equivalent(c2, cas)
+    expect_equal(c2, cas, ignore_attr = TRUE)
 })
 
 require(survey)
