@@ -1,5 +1,3 @@
-context("Standardise (scale) variables")
-
 cas <- smart_read("cas500.csv")
 # cas <- smart_read("tests/testthat/cas500.csv")
 
@@ -9,9 +7,10 @@ test_that("Simple standardization", {
         d$height.std,
         scale(cas$height)[,1]
     )
-    expect_equivalent(
+    expect_equal(
         eval(parse(text = attr(d, "code"))),
-        d
+        d,
+        ignore_attr = TRUE
     )
 })
 
@@ -21,15 +20,16 @@ svy <- svydesign(~dnum+snum, weights = ~pw, fpc = ~fpc1+fpc2, data = apiclus2)
 
 test_that("Standardization works for surveys", {
     d <- standardizeVars(svy, c("api99", "api00"))
-    expect_is(d, "survey.design2")
+    expect_s3_class(d, "survey.design2")
     mu <- svymean(~api00, svy, na.rm = TRUE)
     sd <- sqrt(svyvar(~api00, svy, na.rm = TRUE))
     expect_equal(
         d$variables$api00.std,
         (d$variables$api00 - mu) / sd
     )
-    expect_equivalent(
+    expect_equal(
         eval(parse(text = attr(d, "code"))),
-        d
+        d,
+        ignore_attr = TRUE
     )
 })
